Functions
- document_
highlights - Return all ranges in the document where the word at
positionappears. For$variablesthe search is scope-aware: only occurrences within the same function/method scope are returned, preventing unrelated variables with the same name in other scopes from being highlighted.