Module call_hierarchy

Module call_hierarchy 

Functions

incoming_calls
Find all callers of item.name and return them grouped by enclosing function.
outgoing_calls
Find all calls made by the body of item.name.
prepare_call_hierarchy
Find the declaration matching name and return a CallHierarchyItem.