find_declaration_range

Function find_declaration_range 

pub fn find_declaration_range(
    source: &str,
    doc: &ParsedDoc,
    name: &str,
) -> Option<Range>
Search an AST for a declaration named name, returning its selection range. Used by the PSR-4 fallback in the backend after resolving a class to a file.