find_implementations

Function find_implementations 

pub fn find_implementations(
    word: &str,
    fqn: Option<&str>,
    all_docs: &[(Url, Arc<ParsedDoc>)],
) -> Vec<Location>
Return all Locations where a class declares extends Name or implements Name.

fqn is the fully-qualified name of the symbol (e.g. "App\\Animal"), resolved from the calling file’s use imports. When provided, extends/ implements clauses that spell out the FQN form (\App\Animal or App\Animal) are also matched, in addition to the bare word.