Module document_highlight

Module document_highlight 

Functions

document_highlights
Return all ranges in the document where the word at position appears. For $variables the search is scope-aware: only occurrences within the same function/method scope are returned, preventing unrelated variables with the same name in other scopes from being highlighted.