What kind of symbol the cursor is on. Used to dispatch to the
appropriate semantic walker so that, e.g., searching for get as a
method doesn’t return free-function calls named get.
Find all locations where word is referenced across the given documents.
If include_declaration is true, also includes the declaration site.
Pass kind to restrict results to a particular symbol category; None
falls back to the original word-based walker (better some results than none).
Like find_references but also includes use statement spans.
Used by rename so that use Foo; statements are also updated.
Always uses the general walker (rename must update all occurrence kinds).